==> language-env_0.57.tar.gz: language-env-0.57/tr/dot.Xresources.pl <==
! s comment -*-coding: iso-8859-9;-*-
Xt kitapligini kullanan programlara (or. xterm) iliskin ayarlar
END
Xt kitapln kullanan programlara (r. xterm) ilikin ayarlar
END

# If xterm exists without a luit binary, this is certainly an old version.
if ( -x "/usr/X11R6/bin/xterm" && ! -x "/usr/X11R6/bin/luit" ) {
	print <<"EOF";
! Unicode fonts for UXTerm.
UXTerm*font:            $XFONT_UNI[0]
UXTerm*font1:           $XFONT_UNI[1]
UXTerm*font2:           $XFONT_UNI[2]
UXTerm*font3:           $XFONT_UNI[3]
UXTerm*font4:           $XFONT_UNI[4]
UXTerm*font5:           $XFONT_UNI[5]

! ISO fonts for XTerm.
XTerm*font:             $XFONT_ISO[0]
XTerm*font1:            $XFONT_ISO[1]
XTerm*font2:            $XFONT_ISO[2]
XTerm*font3:            $XFONT_ISO[3]
XTerm*font4:            $XFONT_ISO[4]
XTerm*font5:            $XFONT_ISO[5]

EOF
} else {
	print <<"EOF";
! Needs the luit support in XTerm.
*VT100*locale:          true

! Unicode fonts for XTerm and UXTerm.
*VT100.utf8Fonts.font:  $XFONT_UNI[0]
*VT100.utf8Fonts.font1: $XFONT_UNI[1]
*VT100.utf8Fonts.font2: $XFONT_UNI[2]
*VT100.utf8Fonts.font3: $XFONT_UNI[3]
*VT100.utf8Fonts.font4: $XFONT_UNI[4]
*VT100.utf8Fonts.font5: $XFONT_UNI[5]

! Backward compatible resources for XTerm.
*VT100*font:            $XFONT_UNI[0]
*VT100*font1:           $XFONT_UNI[1]
*VT100*font2:           $XFONT_UNI[2]
*VT100*font3:           $XFONT_UNI[3]
*VT100*font4:           $XFONT_UNI[4]
*VT100*font5:           $XFONT_UNI[5]

EOF
}

print <<"EOF";
! Only XTerm supports Unicode.
rxvt*font:              $XFONT_ISO[0]
rxvt*font1:             $XFONT_ISO[1]
rxvt*font2:             $XFONT_ISO[2]
rxvt*font3:             $XFONT_ISO[3]
rxvt*font4:             $XFONT_ISO[4]
rxvt*font5:             $XFONT_ISO[5]
rxvt*boldFont:          $XFONT_ISO[0]

Aterm*font:             $XFONT_ISO[0]
Aterm*font1:            $XFONT_ISO[1]
Aterm*font2:            $XFONT_ISO[2]
Aterm*font3:            $XFONT_ISO[3]
Aterm*font4:            $XFONT_ISO[4]
Aterm*font5:            $XFONT_ISO[5]
Aterm*boldFont:         $XFONT_ISO[0]

wterm*font:             $XFONT_ISO[0]
wterm*font1:            $XFONT_ISO[1]
wterm*font2:            $XFONT_ISO[2]
wterm*font3:            $XFONT_ISO[3]
wterm*font4:            $XFONT_ISO[4]
wterm*font5:            $XFONT_ISO[5]
wterm*boldFont:         $XFONT_ISO[0]

! Generic font for Turkish.
*font:                  -*-*-medium-r-normal--14-*-*-*-c-*-iso8859-9

! Rxvt like XTerm colors.  See #190939 for rationale.
!*VT100*color0:         black
!*VT100*color1:         red3
!*VT100*color2:         green3
!*VT100*color3:         yellow3
!*VT100*color4:         blue3
!*VT100*color5:         magenta3
!*VT100*color6:         cyan3
!*VT100*color7:         grey90
!*VT100*color8:         grey30
!*VT100*color9:         red
!*VT100*color10:        green
!*VT100*color11:        yellow
!*VT100*color12:        blue
!*VT100*color13:        magenta
!*VT100*color14:        cyan
!*VT100*color15:        white

! Same basic colors for all terminal emulators.
*background:            gray90
*foreground:            black

! Includes also Aterm.
XTerm*reverseVideo:     true
XTerm*boldMode:         false
XTerm*scrollBar:        false
!XTerm*eightBitInput:   true
!XTerm*metaSendsEscape: false

! Rxvt.
rxvt*reverseVideo:      true
rxvt*scrollBar:         false
!rxvt.meta8:            true

! Wterm.
wterm*reverseVideo:     true
wterm*scrollBar:        false
!wterm.meta8:           true
EOF

==> language-env_0.68.tar.gz: language-env-0.68/tr/dot.Xresources.pl <==
! s comment -*-coding: iso-8859-9;-*-
Xt kitapligini kullanan programlara (or. xterm) iliskin ayarlar
END
Xt kitapln kullanan programlara (r. xterm) ilikin ayarlar
END

# If xterm exists without a luit binary, this is certainly an old version.
if ( -x "/usr/X11R6/bin/xterm" && ! -x "/usr/X11R6/bin/luit" ) {
	print <<"EOF";
! Unicode fonts for UXTerm.
UXTerm*font:            $XFONT_UNI[0]
UXTerm*font1:           $XFONT_UNI[1]
UXTerm*font2:           $XFONT_UNI[2]
UXTerm*font3:           $XFONT_UNI[3]
UXTerm*font4:           $XFONT_UNI[4]
UXTerm*font5:           $XFONT_UNI[5]

! ISO fonts for XTerm.
XTerm*font:             $XFONT_ISO[0]
XTerm*font1:            $XFONT_ISO[1]
XTerm*font2:            $XFONT_ISO[2]
XTerm*font3:            $XFONT_ISO[3]
XTerm*font4:            $XFONT_ISO[4]
XTerm*font5:            $XFONT_ISO[5]

EOF
} else {
	print <<"EOF";
! Needs the luit support in XTerm.
*VT100*locale:          true

! Unicode fonts for XTerm and UXTerm.
*VT100.utf8Fonts.font:  $XFONT_UNI[0]
*VT100.utf8Fonts.font1: $XFONT_UNI[1]
*VT100.utf8Fonts.font2: $XFONT_UNI[2]
*VT100.utf8Fonts.font3: $XFONT_UNI[3]
*VT100.utf8Fonts.font4: $XFONT_UNI[4]
*VT100.utf8Fonts.font5: $XFONT_UNI[5]

! Backward compatible resources for XTerm.
*VT100*font:            $XFONT_UNI[0]
*VT100*font1:           $XFONT_UNI[1]
*VT100*font2:           $XFONT_UNI[2]
*VT100*font3:           $XFONT_UNI[3]
*VT100*font4:           $XFONT_UNI[4]
*VT100*font5:           $XFONT_UNI[5]

EOF
}

# Rxvt-unicode supports Unicode and comes with the new Urxvt resource.
if ( -x "/usr/bin/rxvt-unicode" || -x "/usr/bin/urxvt" ) {
	print <<"EOF";
! Unicode fonts for Rxvt (needs 'rxvt-unicode').
rxvt*font:              $XFONT_UNI[0]
rxvt*font1:             $XFONT_UNI[1]
rxvt*font2:             $XFONT_UNI[2]
rxvt*font3:             $XFONT_UNI[3]
rxvt*font4:             $XFONT_UNI[4]
rxvt*font5:             $XFONT_UNI[5]
rxvt*boldFont:          $XFONT_UNI[0]

! Unicode fonts for Urxvt.
urxvt*font:             $XFONT_UNI[0]
urxvt*font1:            $XFONT_UNI[1]
urxvt*font2:            $XFONT_UNI[2]
urxvt*font3:            $XFONT_UNI[3]
urxvt*font4:            $XFONT_UNI[4]
urxvt*font5:            $XFONT_UNI[5]
urxvt*boldFont:         $XFONT_UNI[0]

EOF
} else {
	print <<"EOF";
! ISO fonts for Rxvt.
rxvt*font:              $XFONT_ISO[0]
rxvt*font1:             $XFONT_ISO[1]
rxvt*font2:             $XFONT_ISO[2]
rxvt*font3:             $XFONT_ISO[3]
rxvt*font4:             $XFONT_ISO[4]
rxvt*font5:             $XFONT_ISO[5]
rxvt*boldFont:          $XFONT_ISO[0]
	
EOF
}

print <<"EOF";
! ISO fonts for Aterm.
Aterm*font:             $XFONT_ISO[0]
Aterm*font1:            $XFONT_ISO[1]
Aterm*font2:            $XFONT_ISO[2]
Aterm*font3:            $XFONT_ISO[3]
Aterm*font4:            $XFONT_ISO[4]
Aterm*font5:            $XFONT_ISO[5]
Aterm*boldFont:         $XFONT_ISO[0]

! ISO fonts for Wterm.
wterm*font:             $XFONT_ISO[0]
wterm*font1:            $XFONT_ISO[1]
wterm*font2:            $XFONT_ISO[2]
wterm*font3:            $XFONT_ISO[3]
wterm*font4:            $XFONT_ISO[4]
wterm*font5:            $XFONT_ISO[5]
wterm*boldFont:         $XFONT_ISO[0]

! Generic font for Turkish.
*font:                  -*-*-medium-r-normal--14-*-*-*-c-*-iso8859-9

! Same basic colors for all terminal emulators.
*background:            gray90
*foreground:            black

! Alternative XTerm colors.  See #190939 for rationale.
!*VT100*color0:         black
!*VT100*color1:         red3
!*VT100*color2:         green3
!*VT100*color3:         yellow3
!*VT100*color4:         blue3
!*VT100*color5:         magenta3
!*VT100*color6:         cyan3
!*VT100*color7:         grey90
!*VT100*color8:         grey30
!*VT100*color9:         red
!*VT100*color10:        green
!*VT100*color11:        yellow
!*VT100*color12:        blue
!*VT100*color13:        magenta
!*VT100*color14:        cyan
!*VT100*color15:        white

! Includes also Aterm.
XTerm*reverseVideo:     true
XTerm*boldMode:         false
XTerm*scrollBar:        false
!XTerm*eightBitInput:   true
!XTerm*metaSendsEscape: false

! Rxvt.
rxvt*reverseVideo:      true
rxvt*scrollBar:         false
!rxvt.meta8:            true

EOF

if ( -x "/usr/bin/rxvt-unicode" || -x "/usr/bin/urxvt" ) {
	print <<'EOF';
! Urxvt.
urxvt*reverseVideo:      true
urxvt*scrollBar:         false
!urxvt.meta8:            true

EOF
}

print <<'EOF';
! Wterm.
wterm*reverseVideo:     true
wterm*scrollBar:        false
!wterm.meta8:           true
EOF
